@@ -29,7 +29,7 @@ from pathlib import Path
 import subprocess
 import yaml
 
-from qary.constants import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
+from qary.config import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
 
 logger = logging.getLogger(__name__)
 
@@ -115,6 +115,15 @@ LARGE_FILES['albert_large'] = LARGE_FILES['albert-large-v2']
 LARGE_FILES['albert_large_v2'] = LARGE_FILES['albert-large-v2']
 
 
+LARGE_FILES['stanford_words'] = {
+    'url': 'https://nlp.stanford.edu/~lmthang/morphoNLM/cwCsmRNN.words',
+    'relative_path': 'corpora/stanford.words',
+    'url_filename': 'cwCsmRNN.words',
+    'filename': 'stanford.words',
+    'documentation': "[Better Word Representations with Recursive Neural Networks for Morphology](https://nlp.stanford.edu/~lmthang/morphoNLM/)"
+}
+
+
 ##################################################
 # from pugnlp.futils
 
