@@ -1,16 +1,13 @@
 # TODO: add doc strings?
 import logging
 import importlib
-import sys
 
-from qary import constants
 from qary.skills.base import BotReply
 from qary import spacy_language_model
 import qary.scores  # noqa
 
-sys.path.append(constants.BASE_DIR)
 log = logging.getLogger(__name__)
-log.setLevel(logging.INFO)
+logging.basicConfig(level=logging.INFO)
 
 
 def sentiment_analyzer():
